#!/usr/bin/env python
#
# ESA (C) 2000-2021 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.


import os
import glob
from astropy.io import fits
import pysas.omdrifthist.omdrifthist as omdrifthist


def test_euclid_modulus():
    assert omdrifthist.euclid_modulus((3,4)) == 5


def test_get_platescale():
    pltscl = omdrifthist.get_platescale('U')
    assert pltscl == 0.476513


def test_get_more_recent_ccf():
    list_ccf = os.environ['SAS_CCFPATH']
    list_ccf = list_ccf + ':/ccf/valid'
    folders = list_ccf.split(':')
    om_ccf_list = []
    for folder in folders:
        try:
            om_ccf_file = os.path.abspath(glob.glob(folder + '/OM_ASTR*')[0])
        except IndexError:
            continue
        om_ccf_list.append(om_ccf_file)
    latest_ccf = omdrifthist.get_more_recent_ccf(om_ccf_list)
    print(latest_ccf)
    assert os.path.isfile(latest_ccf)


def test_evaluate_zerodrift():
    with fits.open('test_omdrift.fits') as f:
        header = f[1].header
        assert omdrifthist.evaluate_zerodrift(header) == 1


def test_general():
    dict_values = dict()
    dict_values.update({'set' : 'test_omdrift.fits'})
    dict_values.update({'pages' : '1,2'})
    dict_values.update({'plotfile' : 'test_plot'})
    dict_values.update({'nbins' : 50})
    dict_values.update({'trackradius' : 0.5})
    dict_values.update({'format' : 'png'})
    omdrifthist.run(dict_values)
    assert True


def test_general_pdf():
    dict_values = dict()
    dict_values.update({'set' : 'test_omdrift.fits'})
    dict_values.update({'pages' : '1,2'})
    dict_values.update({'plotfile' : 'plot'})
    dict_values.update({'nbins' : 50})
    dict_values.update({'trackradius' : 0.5})
    dict_values.update({'format' : 'pdf'})
    omdrifthist.run(dict_values)
    assert True

